@@ -150,15 +150,16 @@ var NAVTREEINDEX0 =
 "FaultTolerance.html#TaskRetry":[45,1],
 "Files.html":[55],
 "FrequentlyAskedQuestions.html":[25],
-"FrequentlyAskedQuestions.html#CUDACopyError":[25,11],
+"FrequentlyAskedQuestions.html#CUDACopyError":[25,12],
 "FrequentlyAskedQuestions.html#CUDADrivers":[25,9],
 "FrequentlyAskedQuestions.html#GPUEatingCores":[25,8],
+"FrequentlyAskedQuestions.html#HIPDrivers":[25,10],
 "FrequentlyAskedQuestions.html#HardwareTopology":[25,1],
 "FrequentlyAskedQuestions.html#HowToInitializeAComputationLibraryOnceForEachWorker":[25,0],
-"FrequentlyAskedQuestions.html#IncorrectPerformanceModelFile":[25,12],
+"FrequentlyAskedQuestions.html#IncorrectPerformanceModelFile":[25,13],
 "FrequentlyAskedQuestions.html#InteroperabilityHWLOC":[25,1,0],
 "FrequentlyAskedQuestions.html#On-GPURendering":[25,3],
-"FrequentlyAskedQuestions.html#OpenCLDrivers":[25,10],
+"FrequentlyAskedQuestions.html#OpenCLDrivers":[25,11],
 "FrequentlyAskedQuestions.html#PauseResume":[25,7],
 "FrequentlyAskedQuestions.html#StarPUEatsCPUs":[25,6],
 "FrequentlyAskedQuestions.html#ThreadBindingOnNetBSD":[25,5],
@@ -248,6 +249,5 @@ var NAVTREEINDEX0 =
 "NativeFortranSupport.html":[27],
 "NativeFortranSupport.html#NFAPIMIX":[27,5,1],
 "NativeFortranSupport.html#NFAppCompile":[27,0,3],
-"NativeFortranSupport.html#NFConfiguration":[27,0,1],
-"NativeFortranSupport.html#NFExamples":[27,0,2]
+"NativeFortranSupport.html#NFConfiguration":[27,0,1]
 };
