@@ -1,5 +1,10 @@
 var NAVTREEINDEX11 =
 {
+"group__API__Task__Lists.html#ad80731caf9d45900687caa7d5cc17cae":[57,8,0,1],
+"group__API__Task__Lists.html#af66edbac990d8e894796ca5d5dd45138":[57,8,0,0],
+"group__API__Task__Lists.html#ga02a847856d87dc7027c6f57e22a9e481":[57,8,12],
+"group__API__Task__Lists.html#ga1a9fbeedd7b9b0f77a18a8754a1bdeab":[57,8,13],
+"group__API__Task__Lists.html#ga367d90424e132d762e9a11eac2a822af":[57,8,10],
 "group__API__Task__Lists.html#ga37f7421eb2dcf9d808220db8454f0fac":[57,8,11],
 "group__API__Task__Lists.html#ga5618612b0ce2f914ab9032474ddf072f":[57,8,1],
 "group__API__Task__Lists.html#ga56ae6bd10619777a164ace85197034c4":[57,8,5],
@@ -92,14 +97,14 @@ var NAVTREEINDEX11 =
 "group__API__Toolbox.html":[57,32],
 "group__API__Toolbox.html#ga057b12b615ce9e8a1fe7b5e10d9a5c2e":[57,32,10],
 "group__API__Toolbox.html#ga05ac0dda104331f57d85823a4f9318ce":[57,32,12],
-"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[57,32,21],
+"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[57,32,22],
 "group__API__Toolbox.html#ga10dac0e97a9c6bcc9ae042e067c508ae":[57,32,14],
-"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[57,32,19],
+"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[57,32,20],
 "group__API__Toolbox.html#ga214c60ee1b6cbc27ab08ba6f339ef8e5":[57,32,8],
 "group__API__Toolbox.html#ga230129f89ca986b143c6b059a9229fb7":[57,32,4],
 "group__API__Toolbox.html#ga23742c6fca8b5386e1f3e3f7bbf3a692":[57,32,1],
-"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[57,32,16],
-"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[57,32,17],
+"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[57,32,17],
+"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[57,32,18],
 "group__API__Toolbox.html#ga4456c2db2cc8df7c98d62ecc21b2bd1d":[57,32,2],
 "group__API__Toolbox.html#ga4fc771a29d7dc0e826da42777edbcf15":[57,32,0],
 "group__API__Toolbox.html#ga71e28fc2a0a5267bc7edc0909d9d5117":[57,32,9],
@@ -107,9 +112,10 @@ var NAVTREEINDEX11 =
 "group__API__Toolbox.html#ga7df091d95d10b854c16cd1cd65cf7508":[57,32,6],
 "group__API__Toolbox.html#ga9804db3e8ffb845492154f63e7d6ae95":[57,32,7],
 "group__API__Toolbox.html#ga9e7c20a6cdce868976a0046206b104e6":[57,32,3],
-"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[57,32,18],
-"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[57,32,20],
-"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[57,32,15],
+"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[57,32,19],
+"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[57,32,21],
+"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[57,32,16],
+"group__API__Toolbox.html#gad3ac8d7f5a35aa9c65dcca9915f9a750":[57,32,15],
 "group__API__Toolbox.html#gae07407908792f54312150228d70dbece":[57,32,5],
 "group__API__Toolbox.html#gae8c513ecd1a5bd87a7bdd71260c49ffc":[57,32,11],
 "group__API__Transactions.html":[57,3],
@@ -243,11 +249,5 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[58,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[59,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[58,0,0,2],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[59,0,0,2],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[58,0,0,3],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[59,0,0,3],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[59,0,0,4],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[58,0,0,4],
-"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[58,0,0,5],
-"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[59,0,0,5]
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[59,0,0,2]
 };
