@@ -1,5 +1,10 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Initialization__and__Termination.html#aee75e823857e667c95edf346669b34ed":[57,0,0,18],
+"group__API__Initialization__and__Termination.html#af482c3dac3ed6d28ee51e72c9ad636e1":[57,0,0,17],
+"group__API__Initialization__and__Termination.html#af4d7aba8f400e06ffd8847c7f12e21e7":[57,0,0,8],
+"group__API__Initialization__and__Termination.html#af4da5685fda97febf35c7f02faee66e4":[57,0,0,34],
+"group__API__Initialization__and__Termination.html#aff1ae12be0c8b2366e8ecd0d980af806":[57,0,0,41],
 "group__API__Initialization__and__Termination.html#affd5b335a988c417ecb679d5ecf7c489":[57,0,0,14],
 "group__API__Initialization__and__Termination.html#ga06215a557f489ef2dd936f691e395eb7":[57,0,26],
 "group__API__Initialization__and__Termination.html#ga0702f607811a2af4f7d2bc271eb434e9":[57,0,18],
@@ -244,10 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__MPI__Support.html#ga99eb5ddf622831b720d23268056fa2ae":[57,23,49],
 "group__API__MPI__Support.html#ga9c609f3cc579af484808b3e1b8b787d9":[57,23,87],
 "group__API__MPI__Support.html#ga9d4c92a73afdf0b0fc64dd91e034322e":[57,23,97],
-"group__API__MPI__Support.html#ga9fd0b3f164f98dd59fe52d91868c9709":[57,23,76],
-"group__API__MPI__Support.html#gaa734bb0c57e4a48a7fe6e41f2e563e68":[57,23,34],
-"group__API__MPI__Support.html#gaa823d6398e61516bba887b90ad048914":[57,23,83],
-"group__API__MPI__Support.html#gaa83e001c860c2b132fd5b65cfa99d053":[57,23,67],
-"group__API__MPI__Support.html#gaaa286b76a8a60c508f83741bb371f28c":[57,23,46],
-"group__API__MPI__Support.html#gaad03f0a288bad79078045130b9a83188":[57,23,51]
+"group__API__MPI__Support.html#ga9fd0b3f164f98dd59fe52d91868c9709":[57,23,76]
 };
