@@ -1,5 +1,7 @@
 var NAVTREEINDEX1 =
 {
+"group__API__Codelet__And__Tasks.html#ga104354f28f90926008105218bbdf974e":[5,6,28],
+"group__API__Codelet__And__Tasks.html#ga186aa17aac7d57a205d80033f5f7de4d":[5,6,12],
 "group__API__Codelet__And__Tasks.html#ga18bec8430309a613520d6042d701790d":[5,6,69],
 "group__API__Codelet__And__Tasks.html#ga1c0dac542d81ccdefc3f4aaab2b34c1f":[5,6,45],
 "group__API__Codelet__And__Tasks.html#ga22df1754b8d59c3fa06a366554fa2c3a":[5,6,42],
@@ -247,7 +249,5 @@ var NAVTREEINDEX1 =
 "group__API__Data__Interfaces.html#af9bc59bf8aa5132dcfeaf2c48713b5e1":[5,9,3,4],
 "group__API__Data__Interfaces.html#afa68754d79d58848e3ec781903bdb1a9":[5,9,5,4],
 "group__API__Data__Interfaces.html#afb8adfbac498be2eb6a587460f161e73":[5,9,1,2],
-"group__API__Data__Interfaces.html#afc1c0d3f8d08869ddf5fdda82ef2ac5c":[5,9,0,19],
-"group__API__Data__Interfaces.html#afd365e7e0abc01f07b6d7b9201c4ce22":[5,9,1,10],
-"group__API__Data__Interfaces.html#ga001c8954d20044b466c661cf7c9f9fe0":[5,9,28]
+"group__API__Data__Interfaces.html#afc1c0d3f8d08869ddf5fdda82ef2ac5c":[5,9,0,19]
 };
