@@ -1,5 +1,9 @@
 var NAVTREEINDEX6 =
 {
+"group__API__OpenCL__Extensions.html#ga84a524eaac758722f083ee129a19a567":[5,15,8],
+"group__API__OpenCL__Extensions.html#ga893f462bfed53eff3a54f341488db7ad":[5,15,17],
+"group__API__OpenCL__Extensions.html#ga95184b2188d67976e00bcb4637ac1933":[5,15,31],
+"group__API__OpenCL__Extensions.html#ga9768e086b947961c9db5199e676f05db":[5,15,19],
 "group__API__OpenCL__Extensions.html#ga9a1331f26cc54a1f5406770f68b95d29":[5,15,28],
 "group__API__OpenCL__Extensions.html#ga9e0073e4c839eec6096f6eeca21d7e36":[5,15,25],
 "group__API__OpenCL__Extensions.html#gaa38e7cb3231ed30303e50f46c8f6e39c":[5,15,20],
@@ -245,9 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Perf__Monitoring.html#ga9463d136571c3ab241ac14f72b66144a":[5,38,31],
 "group__API__Perf__Monitoring.html#ga9a48c279f1c93d11e62a0c6c8afaf44d":[5,38,29],
 "group__API__Perf__Monitoring.html#gaab09ff121d4033f737fbe1805db2fc40":[5,38,18],
-"group__API__Perf__Monitoring.html#gab66267d03f0557b14cc3ec0c24c01eba":[5,38,0],
-"group__API__Perf__Monitoring.html#gab6b19fe5667ce4ea447d19d5ed88ae7d":[5,38,20],
-"group__API__Perf__Monitoring.html#gaba3d2e0ac27cf891689bd62805656d5f":[5,38,32],
-"group__API__Perf__Monitoring.html#gac0251242696b1b9c977ce9c73930cbd9":[5,38,9],
-"group__API__Perf__Monitoring.html#gad3a66e71b5a5e3b2e44df2d7326ae73b":[5,38,2]
+"group__API__Perf__Monitoring.html#gab66267d03f0557b14cc3ec0c24c01eba":[5,38,0]
 };
