@@ -1,5 +1,7 @@
 var NAVTREEINDEX3 =
 {
+"group__API__Data__Interfaces.html#gaef6039a7976d3ee6c6916df28a08da1a":[10,9,19],
+"group__API__Data__Interfaces.html#gaefbbb2e643662ee4d7c816d91e8e14df":[10,9,99],
 "group__API__Data__Interfaces.html#gaf011a057a557a66271ce06e8109c11c4":[10,9,73],
 "group__API__Data__Interfaces.html#gaf0937aae4bedeb03e9ebbec36cc1dad6":[10,9,102],
 "group__API__Data__Interfaces.html#gaf0fa0d2dc99ab880ccfe12061770dad2":[10,9,38],
@@ -227,6 +229,7 @@ var NAVTREEINDEX3 =
 "group__API__Explicit__Dependencies.html":[10,11],
 "group__API__Explicit__Dependencies.html#ga19e120568fbd21fcac59b93ff324c45f":[10,11,4],
 "group__API__Explicit__Dependencies.html#ga1a93d3d46ea5ade29a3a3ea76b6eb90d":[10,11,8],
+"group__API__Explicit__Dependencies.html#ga2425f146494ef50105f99325f4120522":[10,11,18],
 "group__API__Explicit__Dependencies.html#ga2ab771900cf19e039ade46594dbc5fce":[10,11,3],
 "group__API__Explicit__Dependencies.html#ga53dc7bff09b441ee6a200cae99ca2cb8":[10,11,5],
 "group__API__Explicit__Dependencies.html#ga6d09446c8849f42edeced84c558e6a49":[10,11,17],
@@ -246,8 +249,5 @@ var NAVTREEINDEX3 =
 "group__API__FFT__Support.html":[10,1],
 "group__API__FFT__Support.html#ga22ad2f1c869305d11132322039d38876":[10,1,6],
 "group__API__FFT__Support.html#ga2b1a62489b5b48491067bc8dc39f4b16":[10,1,8],
-"group__API__FFT__Support.html#ga4670f7ac8c6980f78b80b48bbe561299":[10,1,7],
-"group__API__FFT__Support.html#ga642104c645445688177f1a44afeeefb0":[10,1,1],
-"group__API__FFT__Support.html#ga8e37e0bd1edc887cf456dcf7d95b86c4":[10,1,3],
-"group__API__FFT__Support.html#gabf7989748571ab9155a865a19002d1fa":[10,1,0]
+"group__API__FFT__Support.html#ga4670f7ac8c6980f78b80b48bbe561299":[10,1,7]
 };
