@@ -1,5 +1,9 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5":[10,22,52],
+"group__API__Modularized__Scheduler.html#ga90dfe435a72d46bd23ddaffa287833c2":[10,22,40],
+"group__API__Modularized__Scheduler.html#ga966aaa040948551bede3ee46c9f8847e":[10,22,18],
+"group__API__Modularized__Scheduler.html#ga9bfbf9eb07c5ccc7c77a40ddb37056b8":[10,22,68],
 "group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d":[10,22,44],
 "group__API__Modularized__Scheduler.html#gaa207453a69f029b2f3c74bc8b9cffde2":[10,22,70],
 "group__API__Modularized__Scheduler.html#gaa838921844068ca3190dca5e2b5a99db":[10,22,13],
@@ -245,9 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Parallel__Worker.html#ga31b276cab21a22cc08401a6126c862c1":[10,37,31],
 "group__API__Parallel__Worker.html#ga3364354b5ce437fb90744581504dc672":[10,37,19],
 "group__API__Parallel__Worker.html#ga33b7a5642e7e44f192631f0a27df99c0":[10,37,35],
-"group__API__Parallel__Worker.html#ga3f0e66f06b1692257c085f2340e219a6":[10,37,14],
-"group__API__Parallel__Worker.html#ga4e3f3eec12a1cd4285a3f8938a9c240d":[10,37,4],
-"group__API__Parallel__Worker.html#ga5d4d41c174aac7219a8ec9dd4136ace6":[10,37,12],
-"group__API__Parallel__Worker.html#ga5dc009221d5edb074372761574238dac":[10,37,6],
-"group__API__Parallel__Worker.html#ga63c001ace567446514f1616e34af1bf6":[10,37,29]
+"group__API__Parallel__Worker.html#ga3f0e66f06b1692257c085f2340e219a6":[10,37,14]
 };
