@@ -1,5 +1,9 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#a81af53e5f8e59cb12d6d0b378c4b5268":[10,24,0,12],
+"group__API__Scheduling__Policy.html#a84231c0bc118e91e49b0614c24b9de4a":[10,24,0,4],
+"group__API__Scheduling__Policy.html#a9020a364719389cd19c31a657c938293":[10,24,0,10],
+"group__API__Scheduling__Policy.html#ace93b3c465e39c7e2ca894406905dc2a":[10,24,0,0],
 "group__API__Scheduling__Policy.html#ad720f2cd2155e8baa10f57792b68a5eb":[10,24,0,8],
 "group__API__Scheduling__Policy.html#afd00e4e0a058e043c3d8edf916ace4f7":[10,24,0,7],
 "group__API__Scheduling__Policy.html#ga1e159d56ffa2d7705bdfd1ceb93e0d64":[10,24,36],
@@ -190,14 +194,14 @@ var NAVTREEINDEX9 =
 "group__API__Toolbox.html":[10,35],
 "group__API__Toolbox.html#ga057b12b615ce9e8a1fe7b5e10d9a5c2e":[10,35,10],
 "group__API__Toolbox.html#ga05ac0dda104331f57d85823a4f9318ce":[10,35,12],
-"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[10,35,21],
+"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[10,35,22],
 "group__API__Toolbox.html#ga10dac0e97a9c6bcc9ae042e067c508ae":[10,35,14],
-"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[10,35,19],
+"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[10,35,20],
 "group__API__Toolbox.html#ga214c60ee1b6cbc27ab08ba6f339ef8e5":[10,35,8],
 "group__API__Toolbox.html#ga230129f89ca986b143c6b059a9229fb7":[10,35,4],
 "group__API__Toolbox.html#ga23742c6fca8b5386e1f3e3f7bbf3a692":[10,35,1],
-"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[10,35,16],
-"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[10,35,17],
+"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[10,35,17],
+"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[10,35,18],
 "group__API__Toolbox.html#ga4456c2db2cc8df7c98d62ecc21b2bd1d":[10,35,2],
 "group__API__Toolbox.html#ga4fc771a29d7dc0e826da42777edbcf15":[10,35,0],
 "group__API__Toolbox.html#ga71e28fc2a0a5267bc7edc0909d9d5117":[10,35,9],
@@ -205,9 +209,10 @@ var NAVTREEINDEX9 =
 "group__API__Toolbox.html#ga7df091d95d10b854c16cd1cd65cf7508":[10,35,6],
 "group__API__Toolbox.html#ga9804db3e8ffb845492154f63e7d6ae95":[10,35,7],
 "group__API__Toolbox.html#ga9e7c20a6cdce868976a0046206b104e6":[10,35,3],
-"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[10,35,18],
-"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[10,35,20],
-"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[10,35,15],
+"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[10,35,19],
+"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[10,35,21],
+"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[10,35,16],
+"group__API__Toolbox.html#gad3ac8d7f5a35aa9c65dcca9915f9a750":[10,35,15],
 "group__API__Toolbox.html#gae07407908792f54312150228d70dbece":[10,35,5],
 "group__API__Toolbox.html#gae8c513ecd1a5bd87a7bdd71260c49ffc":[10,35,11],
 "group__API__Transactions.html":[10,7],
@@ -244,10 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#ga178dd465219373d9da366fff593d56fa":[10,18,17],
 "group__API__Workers.html#ga1c6e6bcceeb1c5d4edafa9d933d15cc2":[10,18,23],
 "group__API__Workers.html#ga1c9cefba8ede1b63cef4a617a73f7d2c":[10,18,54],
-"group__API__Workers.html#ga1d20d159f519df135fb1ac954a29bccf":[10,18,58],
-"group__API__Workers.html#ga21213e018976d3876c85d3ca9ac1dff9":[10,18,31],
-"group__API__Workers.html#ga2b75b2600f85996e943ece2631971c62":[10,18,13],
-"group__API__Workers.html#ga2c930d982bacf4bf4dce015ab2d61123":[10,18,66],
-"group__API__Workers.html#ga35c8908fd60c0407901872b25a8a88da":[10,18,68],
-"group__API__Workers.html#ga389142e108345483dc8c0bf07465263c":[10,18,49]
+"group__API__Workers.html#ga1d20d159f519df135fb1ac954a29bccf":[10,18,58]
 };
