@@ -263,19 +263,19 @@ var NAVTREEINDEX =
 [
 "AdvancedDataManagement.html",
 "group__API__Bitmap.html#ga13e39b685a536b85ed319cfcb97743a4",
-"group__API__Codelet__And__Tasks.html#gga0088c4ab87a08b3e7a375c1a79e91202a5ee20d5e9ae6d031161f7d601f5c44ee",
-"group__API__Data__Interfaces.html#ga7e3ef9efbc7a65adad27f9ac27493493",
-"group__API__Data__Partition.html#ga46d2b144a7de2e17d17b1383ef5f522d",
-"group__API__Insert__Task.html#ga4c7656d210572e4fa1860c290af2acfb",
-"group__API__Miscellaneous__Helpers.html",
-"group__API__OpenMP__Runtime__Support.html#gaa63576df9729394a3d53137d7021bab5",
-"group__API__Performance__Model.html#aa22dc6b2674ed810366dc300f4abd7cc",
-"group__API__SC__Hypervisor__usage.html#ga5f2b33a41a697759ee2a222e623f723c",
-"group__API__Threads.html#ga629152a86070cd58811fa17506f7995e",
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html",
-"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__init.html",
-"interfacefstarpu__mod_1_1fstarpu__void__data__register.html",
-"starpu__profiling__tool_8h_source.html"
+"group__API__Codelet__And__Tasks.html#gga0088c4ab87a08b3e7a375c1a79e91202a4c0208c26be7e843a8360b0f74432c04",
+"group__API__Data__Interfaces.html#ga7cc322b2f03830ec7afbb58b7416a283",
+"group__API__Data__Partition.html#ga3b80f74f636512662d0d5a4a162ff537",
+"group__API__Insert__Task.html#ga45ae06dad37b9a8518198b1c3b06f276",
+"group__API__Max__FPGA__Extensions.html#ga6dfcf82c7b941a50a9bc2e478dfc4897",
+"group__API__OpenMP__Runtime__Support.html#gaa15212ca3137d7aba827794b26fee9e0",
+"group__API__Performance__Model.html#a8c4568a5722baebd67148642ee3377e1",
+"group__API__SC__Hypervisor__usage.html#ga15d008933c3c89906f613b3a24fff3cc",
+"group__API__Threads.html#ga4f00fbbe6f909998ecec7c3cc3715e21",
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html",
+"interfacefstarpu__mod_1_1fstarpu__memory__pin.html",
+"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html",
+"starpu__perf__steering_8h.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
