@@ -1,5 +1,7 @@
 var NAVTREEINDEX3 =
 {
+"group__API__Data__Interfaces.html#ga7cc322b2f03830ec7afbb58b7416a283":[25,9,65],
+"group__API__Data__Interfaces.html#ga7d44b8a0594932a8cece13e1cc9932bb":[25,9,72],
 "group__API__Data__Interfaces.html#ga7e3ef9efbc7a65adad27f9ac27493493":[25,9,139],
 "group__API__Data__Interfaces.html#ga7ea069447f11e836d7b709c97d90b570":[25,9,108],
 "group__API__Data__Interfaces.html#ga81160c064d381e20cf874ec053e167f9":[25,9,166],
@@ -247,7 +249,5 @@ var NAVTREEINDEX3 =
 "group__API__Data__Partition.html#ga29e07c2c0604da63e7746a8018d8a62f":[25,10,3],
 "group__API__Data__Partition.html#ga2b713d3a7a34dfd7416135d071aa3e48":[25,10,81],
 "group__API__Data__Partition.html#ga305da4bdb4c0990aa53dbcc8f5dd4678":[25,10,76],
-"group__API__Data__Partition.html#ga3233e3203e0541138cce8152c3ab9aa0":[25,10,56],
-"group__API__Data__Partition.html#ga3b80f74f636512662d0d5a4a162ff537":[25,10,82],
-"group__API__Data__Partition.html#ga3d4ca379476ef347e2001fa8dc177e6a":[25,10,87]
+"group__API__Data__Partition.html#ga3233e3203e0541138cce8152c3ab9aa0":[25,10,56]
 };
