@@ -1,5 +1,7 @@
 var NAVTREEINDEX4 =
 {
+"group__API__Data__Partition.html#ga3b80f74f636512662d0d5a4a162ff537":[25,10,82],
+"group__API__Data__Partition.html#ga3d4ca379476ef347e2001fa8dc177e6a":[25,10,87],
 "group__API__Data__Partition.html#ga46d2b144a7de2e17d17b1383ef5f522d":[25,10,17],
 "group__API__Data__Partition.html#ga47a12b7cc94a8bff0654761c36b8105d":[25,10,42],
 "group__API__Data__Partition.html#ga4b910784c11bb46599fe9cb8928418f2":[25,10,27],
@@ -80,6 +82,7 @@ var NAVTREEINDEX4 =
 "group__API__Explicit__Dependencies.html":[25,11],
 "group__API__Explicit__Dependencies.html#ga19e120568fbd21fcac59b93ff324c45f":[25,11,4],
 "group__API__Explicit__Dependencies.html#ga1a93d3d46ea5ade29a3a3ea76b6eb90d":[25,11,8],
+"group__API__Explicit__Dependencies.html#ga2425f146494ef50105f99325f4120522":[25,11,18],
 "group__API__Explicit__Dependencies.html#ga2ab771900cf19e039ade46594dbc5fce":[25,11,3],
 "group__API__Explicit__Dependencies.html#ga53dc7bff09b441ee6a200cae99ca2cb8":[25,11,5],
 "group__API__Explicit__Dependencies.html#ga6d09446c8849f42edeced84c558e6a49":[25,11,17],
@@ -118,6 +121,7 @@ var NAVTREEINDEX4 =
 "group__API__FxT__Support.html#ad989ef1acebea5296285ba1543b9b8d3":[25,34,2,2],
 "group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c":[25,34,1,0],
 "group__API__FxT__Support.html#ae8b5695146698ba1d5aef8c9237b5272":[25,34,2,3],
+"group__API__FxT__Support.html#ga044878f9b946fd4c265ba6e725e2468c":[25,34,9],
 "group__API__FxT__Support.html#ga2e55ad671e94b6161755717b1c8b44c1":[25,34,7],
 "group__API__FxT__Support.html#ga52a3e1a95689315f0b789a3325ec2a90":[25,34,5],
 "group__API__FxT__Support.html#ga5793bf5c8fc0bedf76d18a5fa38593df":[25,34,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__Insert__Task.html#ga30d3c482ec1e2b9b6868988abcb02596":[25,13,7],
 "group__API__Insert__Task.html#ga3430e41717b3d455305bf7125cee8199":[25,13,61],
 "group__API__Insert__Task.html#ga37a139a27b04d2d36fe3ecb8ea3055c8":[25,13,50],
-"group__API__Insert__Task.html#ga4059498df9881ac78c64569ac5ab94d8":[25,13,26],
-"group__API__Insert__Task.html#ga45ae06dad37b9a8518198b1c3b06f276":[25,13,11],
-"group__API__Insert__Task.html#ga4b1b5556ee05f2f4e4cbad5892082e33":[25,13,32],
-"group__API__Insert__Task.html#ga4b5caeffe3cf93e3ac500eb432e48f2f":[25,13,13],
-"group__API__Insert__Task.html#ga4bfd2fa129496a5356e64db16734a10e":[25,13,41]
+"group__API__Insert__Task.html#ga4059498df9881ac78c64569ac5ab94d8":[25,13,26]
 };
