@@ -1,5 +1,9 @@
 var NAVTREEINDEX5 =
 {
+"group__API__Insert__Task.html#ga45ae06dad37b9a8518198b1c3b06f276":[25,13,11],
+"group__API__Insert__Task.html#ga4b1b5556ee05f2f4e4cbad5892082e33":[25,13,32],
+"group__API__Insert__Task.html#ga4b5caeffe3cf93e3ac500eb432e48f2f":[25,13,13],
+"group__API__Insert__Task.html#ga4bfd2fa129496a5356e64db16734a10e":[25,13,41],
 "group__API__Insert__Task.html#ga4c7656d210572e4fa1860c290af2acfb":[25,13,25],
 "group__API__Insert__Task.html#ga502e5ec7928054775798a57a930bb12b":[25,13,55],
 "group__API__Insert__Task.html#ga51d0a8fa43d9289b8c9da5450faf76ad":[25,13,52],
@@ -245,9 +249,5 @@ var NAVTREEINDEX5 =
 "group__API__MPI__Support.html#structstarpu__mpi__task__exchange__params":[25,27,0],
 "group__API__Max__FPGA__Extensions.html":[25,17],
 "group__API__Max__FPGA__Extensions.html#a2cf83f64b309bdafcc1f30691b660d88":[25,17,0,0],
-"group__API__Max__FPGA__Extensions.html#a7c29ba6b31ef6459b19e9ab0461b828c":[25,17,0,1],
-"group__API__Max__FPGA__Extensions.html#ga6dfcf82c7b941a50a9bc2e478dfc4897":[25,17,1],
-"group__API__Max__FPGA__Extensions.html#ga7f7a92414ff1a98d7523bc40f36d0878":[25,17,2],
-"group__API__Max__FPGA__Extensions.html#gaab45e70c85fc1786d6d5e618fd5c3922":[25,17,3],
-"group__API__Max__FPGA__Extensions.html#structstarpu__max__load":[25,17,0]
+"group__API__Max__FPGA__Extensions.html#a7c29ba6b31ef6459b19e9ab0461b828c":[25,17,0,1]
 };
