@@ -1,5 +1,9 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Performance__Model.html#a8c4568a5722baebd67148642ee3377e1":[25,20,4,12],
+"group__API__Performance__Model.html#a8ddcc5e8aeaf6dd2459e883fab483409":[25,20,4,5],
+"group__API__Performance__Model.html#a9d94e688cfa6eef3f277047e2a0e7cb2":[25,20,6,10],
+"group__API__Performance__Model.html#a9e662c85f8bb1e134d4885c77ba8a32f":[25,20,2,4],
 "group__API__Performance__Model.html#aa22dc6b2674ed810366dc300f4abd7cc":[25,20,6,9],
 "group__API__Performance__Model.html#aa69cc173b9ebdbf129eb1b30ca64ddd9":[25,20,4,7],
 "group__API__Performance__Model.html#aa82fae955253d333733d34fe4a44e298":[25,20,5,1],
@@ -245,9 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__SC__Hypervisor__usage.html#ga07b07d1fe5d41055f451fc92c60361e1":[25,49,1],
 "group__API__SC__Hypervisor__usage.html#ga0a20609c85fa479c3fd5892399099416":[25,49,3],
 "group__API__SC__Hypervisor__usage.html#ga0f47fee9448054de82ed44f1cb18fdde":[25,49,22],
-"group__API__SC__Hypervisor__usage.html#ga1366fc9bb28170e9012dcad441696e52":[25,49,13],
-"group__API__SC__Hypervisor__usage.html#ga15d008933c3c89906f613b3a24fff3cc":[25,49,0],
-"group__API__SC__Hypervisor__usage.html#ga37713b9ab6d282f2b705240e630f1a4c":[25,49,10],
-"group__API__SC__Hypervisor__usage.html#ga4c83e2984867267ea8c7da9fbaf23858":[25,49,2],
-"group__API__SC__Hypervisor__usage.html#ga4dfbeda855bb8963c5332fdd796c0dcf":[25,49,18]
+"group__API__SC__Hypervisor__usage.html#ga1366fc9bb28170e9012dcad441696e52":[25,49,13]
 };
