@@ -1,5 +1,9 @@
 var NAVTREEINDEX9 =
 {
+"group__API__SC__Hypervisor__usage.html#ga15d008933c3c89906f613b3a24fff3cc":[25,49,0],
+"group__API__SC__Hypervisor__usage.html#ga37713b9ab6d282f2b705240e630f1a4c":[25,49,10],
+"group__API__SC__Hypervisor__usage.html#ga4c83e2984867267ea8c7da9fbaf23858":[25,49,2],
+"group__API__SC__Hypervisor__usage.html#ga4dfbeda855bb8963c5332fdd796c0dcf":[25,49,18],
 "group__API__SC__Hypervisor__usage.html#ga5f2b33a41a697759ee2a222e623f723c":[25,49,4],
 "group__API__SC__Hypervisor__usage.html#ga5f34faa17f98f25bd874950ba1a15578":[25,49,15],
 "group__API__SC__Hypervisor__usage.html#ga6398be50d801f0fc5ad73506e392d476":[25,49,17],
@@ -245,9 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Threads.html#ga402f8687fe2f6f7277c692fa6c1d0d29":[25,3,36],
 "group__API__Threads.html#ga42b7eaa98fe66b90eb67f3fdb51fd14d":[25,3,20],
 "group__API__Threads.html#ga43ef5044dfe6169c422d3ded42aa69e4":[25,3,1],
-"group__API__Threads.html#ga4b4dc49f4d02c93e9b5364e9fb8f148f":[25,3,33],
-"group__API__Threads.html#ga4f00fbbe6f909998ecec7c3cc3715e21":[25,3,55],
-"group__API__Threads.html#ga5bc60d93e1403658c30c998d1b6edd11":[25,3,52],
-"group__API__Threads.html#ga5e53025adc42966a97d616304bd654bd":[25,3,6],
-"group__API__Threads.html#ga5ec606cedc543ee35f3c7dc8a8e2505b":[25,3,64]
+"group__API__Threads.html#ga4b4dc49f4d02c93e9b5364e9fb8f148f":[25,3,33]
 };
