@@ -1,5 +1,11 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#gaa6e5fd90ba1b431ed025006d190fb421":[5,18,5],
+"group__API__Workers.html#gaa7a73dac05f65d5760abf29016e251f0":[5,18,3],
+"group__API__Workers.html#gaad05388dbafdd5397ebe080913a7b0c8":[5,18,19],
+"group__API__Workers.html#gaafe3ee2f7b074f95e8bc79eeabda0f0f":[5,18,4],
+"group__API__Workers.html#gab0ffe5622c5980444226f1ed8d6fee71":[5,18,27],
+"group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[5,18,12],
 "group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04":[5,18,65],
 "group__API__Workers.html#gabb530cc7597d5a135b900760f45c9cde":[5,18,61],
 "group__API__Workers.html#gac043c52077692456604a2f2f161b86ba":[5,18,57],
@@ -44,54 +50,54 @@ var NAVTREEINDEX10 =
 "group__API__Workers.html#structstarpu__sched__ctx__iterator":[5,18,0],
 "group__API__Workers.html#structstarpu__worker__collection":[5,18,1],
 "index.html":[],
-"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[6,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[7,0,0,0],
-"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[7,0,0,1],
+"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[6,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[6,0,0,1],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[6,0,0,2],
+"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[7,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[7,0,0,2],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[7,0,0,3],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[6,0,0,2],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[6,0,0,3],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[7,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[6,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[7,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[6,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[7,0,0,5],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[7,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[6,0,0,6],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[7,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[7,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[6,0,0,7],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[6,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[7,0,0,8],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[6,0,0,9],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[6,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[7,0,0,9],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[6,0,0,10],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[6,0,0,9],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[7,0,0,10],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[6,0,0,11],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[6,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[7,0,0,11],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[6,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[6,0,0,12],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[7,0,0,12],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[7,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[6,0,0,13],
-"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[6,0,0,14],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[7,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[7,0,0,14],
+"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[6,0,0,14],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[7,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[6,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[6,0,0,16],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[7,0,0,16],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[6,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[7,0,0,17],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[6,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[6,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[7,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[6,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[7,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[6,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[7,0,0,20],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[7,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[6,0,0,21],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[7,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[6,0,0,22],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[7,0,0,22],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[6,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[7,0,0,23],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[6,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[6,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[7,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[6,0,0,25],
@@ -104,22 +110,22 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[7,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[6,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[7,0,0,29],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[7,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[6,0,0,30],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[7,0,0,31],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[7,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[6,0,0,31],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[7,0,0,32],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[7,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[6,0,0,32],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[6,0,0,33],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[7,0,0,32],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[7,0,0,33],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[7,0,0,34],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[6,0,0,33],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[6,0,0,34],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[7,0,0,34],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[7,0,0,35],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[6,0,0,35],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[6,0,0,36],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[7,0,0,36],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[7,0,0,37],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[6,0,0,36],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[6,0,0,37],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[7,0,0,37],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[7,0,0,38],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[6,0,0,38],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[7,0,0,39],
@@ -158,34 +164,34 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[6,0,0,55],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[7,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[6,0,0,56],
-"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[6,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[7,0,0,57],
-"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[6,0,0,58],
+"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[6,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[7,0,0,58],
-"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[6,0,0,59],
+"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[6,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[7,0,0,59],
+"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[6,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[6,0,0,60],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[7,0,0,60],
-"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[7,0,0,61],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[6,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[7,0,0,61],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[6,0,0,62],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[7,0,0,62],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[6,0,0,63],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[7,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[6,0,0,64],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[7,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[6,0,0,64],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[6,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[7,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[6,0,0,66],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[7,0,0,66],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[6,0,0,67],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[7,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,68],
 "interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[6,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[7,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,68],
 "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[6,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[7,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[7,0,0,69],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[6,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[7,0,0,70],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[7,0,0,71],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[6,0,0,71],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[7,0,0,72],
@@ -200,54 +206,48 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[6,0,0,76],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[7,0,0,77],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[6,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[6,0,0,78],
 "interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[7,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[6,0,0,79],
+"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[6,0,0,78],
 "interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[7,0,0,79],
+"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[6,0,0,79],
 "interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[7,0,0,80],
 "interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[6,0,0,80],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[7,0,0,81],
 "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[6,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[7,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[7,0,0,81],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[6,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[6,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[7,0,0,82],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[7,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[6,0,0,83],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[7,0,0,84],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[6,0,0,84],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[7,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[6,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[7,0,0,86],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[6,0,0,86],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[6,0,0,87],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[7,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[6,0,0,88],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[6,0,0,87],
 "interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[7,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[6,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[6,0,0,88],
 "interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[7,0,0,89],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[7,0,0,90],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[6,0,0,89],
 "interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[6,0,0,90],
+"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[7,0,0,90],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[6,0,0,91],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[7,0,0,91],
 "interfacefstarpu__mod_1_1fstarpu__data__partition.html":[6,0,0,92],
 "interfacefstarpu__mod_1_1fstarpu__data__partition.html":[7,0,0,92],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[7,0,0,93],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[6,0,0,93],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[7,0,0,94],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[7,0,0,93],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[6,0,0,94],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[7,0,0,94],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[6,0,0,95],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[7,0,0,95],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[7,0,0,96],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[6,0,0,96],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[7,0,0,97],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[7,0,0,96],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[6,0,0,97],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[7,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[7,0,0,97],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[6,0,0,98],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[7,0,0,99],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[7,0,0,98],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[6,0,0,99],
-"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[7,0,0,100],
-"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[6,0,0,100],
-"interfacefstarpu__mod_1_1fstarpu__data__release.html":[7,0,0,101],
-"interfacefstarpu__mod_1_1fstarpu__data__release.html":[6,0,0,101],
-"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[6,0,0,102],
-"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[7,0,0,102]
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[7,0,0,99]
 };
