@@ -1,5 +1,10 @@
 var NAVTREEINDEX5 =
 {
+"group__API__MPI__Support.html#ga1998499da59f8849a7ee5de16b0f5bab":[5,27,48],
+"group__API__MPI__Support.html#ga1d0194c08bd343a68c833f449fb62fa8":[5,27,33],
+"group__API__MPI__Support.html#ga1def2741166f560a0fb91f012538087f":[5,27,117],
+"group__API__MPI__Support.html#ga223329eeb7c711b1b213604355981185":[5,27,7],
+"group__API__MPI__Support.html#ga234e28905c976ed1b03fcdf75812a06d":[5,27,23],
 "group__API__MPI__Support.html#ga23d04f0a7ca146314a02e4773dafde2e":[5,27,60],
 "group__API__MPI__Support.html#ga25408759187b030c633314855589ebcd":[5,27,91],
 "group__API__MPI__Support.html#ga2816a57287cd1a4babd27105936fc6ed":[5,27,109],
@@ -244,10 +249,5 @@ var NAVTREEINDEX5 =
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component":[5,22,0],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__fifo__data":[5,22,2],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__heteroprio__data":[5,22,5],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__component__mct__data":[5,22,4],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__component__perfmodel__select__data":[5,22,6],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__component__prio__data":[5,22,3],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__component__specs":[5,22,7],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__tree":[5,22,1],
-"group__API__OpenCL__Extensions.html":[5,15]
+"group__API__Modularized__Scheduler.html#structstarpu__sched__component__mct__data":[5,22,4]
 };
