@@ -1,5 +1,10 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Perf__Monitoring.html#ga0a9c21a6b765059a5f5f72ab10dd99fa":[5,38,12],
+"group__API__Perf__Monitoring.html#ga0d09d776a8250c995d3e40d77bb10628":[5,38,33],
+"group__API__Perf__Monitoring.html#ga13f8e7f707f5bab7bc4f45291effd109":[5,38,15],
+"group__API__Perf__Monitoring.html#ga15b96ecd4161e8abdea440ad89262766":[5,38,24],
+"group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[5,38,1],
 "group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e":[5,38,11],
 "group__API__Perf__Monitoring.html#ga2f9ddf6ae47cd7eba9b94499e37a301f":[5,38,13],
 "group__API__Perf__Monitoring.html#ga36c44ab10f14200d43704d8771246997":[5,38,8],
@@ -244,10 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling__Tool.html#ga459877aae774d6576396522f2f7a935a":[5,41,4],
 "group__API__Profiling__Tool.html#ga51982063f84be225d47f8a0635184fe8":[5,41,6],
 "group__API__Profiling__Tool.html#ga9b4062bc6c18544ad5a1282672adb644":[5,41,7],
-"group__API__Profiling__Tool.html#structstarpu__prof__tool__api__info":[5,41,2],
-"group__API__Profiling__Tool.html#structstarpu__prof__tool__info":[5,41,0],
-"group__API__Profiling__Tool.html#unionstarpu__prof__tool__event__info":[5,41,1],
-"group__API__Random__Functions.html":[5,42],
-"group__API__Running__Drivers.html":[5,32],
-"group__API__Running__Drivers.html#a08415dd427f53b10ce4176ad77fade39":[5,32,0,1]
+"group__API__Profiling__Tool.html#structstarpu__prof__tool__api__info":[5,41,2]
 };
