@@ -1,5 +1,7 @@
 var NAVTREEINDEX2 =
 {
+"group__API__Data__Interfaces.html#adf548c64da75d9ba392aec9f6cbb8884":[7,9,1,7],
+"group__API__Data__Interfaces.html#ae002548f6392819ff90d72f64898dca6":[7,9,1,11],
 "group__API__Data__Interfaces.html#ae039cff4622424d30f99811665f4de4f":[7,9,10,6],
 "group__API__Data__Interfaces.html#ae04050a90bd86fe5b8462b62aaa9547e":[7,9,0,16],
 "group__API__Data__Interfaces.html#ae1d888af673475dbcf85104b6c359a6e":[7,9,0,12],
@@ -247,7 +249,5 @@ var NAVTREEINDEX2 =
 "group__API__Data__Interfaces.html#structstarpu__csr__interface":[7,9,9],
 "group__API__Data__Interfaces.html#structstarpu__data__copy__methods":[7,9,0],
 "group__API__Data__Interfaces.html#structstarpu__data__interface__ops":[7,9,1],
-"group__API__Data__Interfaces.html#structstarpu__matrix__interface":[7,9,2],
-"group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops":[7,9,11],
-"group__API__Data__Interfaces.html#structstarpu__multiformat__interface":[7,9,12]
+"group__API__Data__Interfaces.html#structstarpu__matrix__interface":[7,9,2]
 };
