@@ -1,5 +1,9 @@
 var NAVTREEINDEX5 =
 {
+"group__API__MPI__Support.html#ga0ec1ce958654468b20224c9ae772f98f":[7,27,22],
+"group__API__MPI__Support.html#ga1998499da59f8849a7ee5de16b0f5bab":[7,27,48],
+"group__API__MPI__Support.html#ga1d0194c08bd343a68c833f449fb62fa8":[7,27,33],
+"group__API__MPI__Support.html#ga1def2741166f560a0fb91f012538087f":[7,27,117],
 "group__API__MPI__Support.html#ga223329eeb7c711b1b213604355981185":[7,27,7],
 "group__API__MPI__Support.html#ga234e28905c976ed1b03fcdf75812a06d":[7,27,23],
 "group__API__MPI__Support.html#ga23d04f0a7ca146314a02e4773dafde2e":[7,27,60],
@@ -245,9 +249,5 @@ var NAVTREEINDEX5 =
 "group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea40dba09874d6d3a220669e0ccea27da2":[7,22,26,1],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component":[7,22,0],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__fifo__data":[7,22,2],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__component__heteroprio__data":[7,22,5],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__component__mct__data":[7,22,4],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__component__perfmodel__select__data":[7,22,6],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__component__prio__data":[7,22,3],
-"group__API__Modularized__Scheduler.html#structstarpu__sched__component__specs":[7,22,7]
+"group__API__Modularized__Scheduler.html#structstarpu__sched__component__heteroprio__data":[7,22,5]
 };
