@@ -1,5 +1,9 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#ga8004f14208fd9b29f36440dc11ca765b":[7,24,25],
+"group__API__Scheduling__Policy.html#ga87e2aacf5892951d5333a3421e90f278":[7,24,33],
+"group__API__Scheduling__Policy.html#ga8e58ffd062043cf25b47c081b7f6ba88":[7,24,47],
+"group__API__Scheduling__Policy.html#ga8eb834f05df5337dcd8c96f6a74cd1f1":[7,24,41],
 "group__API__Scheduling__Policy.html#ga9424eb90a56d08f804d85be6557ddf66":[7,24,45],
 "group__API__Scheduling__Policy.html#ga94edfd4a02666d8c1b8c506423586426":[7,24,19],
 "group__API__Scheduling__Policy.html#ga98ec28ae7ac484959f48b7a79372c1af":[7,24,31],
@@ -157,14 +161,14 @@ var NAVTREEINDEX9 =
 "group__API__Toolbox.html":[7,35],
 "group__API__Toolbox.html#ga057b12b615ce9e8a1fe7b5e10d9a5c2e":[7,35,10],
 "group__API__Toolbox.html#ga05ac0dda104331f57d85823a4f9318ce":[7,35,12],
-"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[7,35,21],
+"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[7,35,22],
 "group__API__Toolbox.html#ga10dac0e97a9c6bcc9ae042e067c508ae":[7,35,14],
-"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[7,35,19],
+"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[7,35,20],
 "group__API__Toolbox.html#ga214c60ee1b6cbc27ab08ba6f339ef8e5":[7,35,8],
 "group__API__Toolbox.html#ga230129f89ca986b143c6b059a9229fb7":[7,35,4],
 "group__API__Toolbox.html#ga23742c6fca8b5386e1f3e3f7bbf3a692":[7,35,1],
-"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[7,35,16],
-"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[7,35,17],
+"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[7,35,17],
+"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[7,35,18],
 "group__API__Toolbox.html#ga4456c2db2cc8df7c98d62ecc21b2bd1d":[7,35,2],
 "group__API__Toolbox.html#ga4fc771a29d7dc0e826da42777edbcf15":[7,35,0],
 "group__API__Toolbox.html#ga71e28fc2a0a5267bc7edc0909d9d5117":[7,35,9],
@@ -172,9 +176,10 @@ var NAVTREEINDEX9 =
 "group__API__Toolbox.html#ga7df091d95d10b854c16cd1cd65cf7508":[7,35,6],
 "group__API__Toolbox.html#ga9804db3e8ffb845492154f63e7d6ae95":[7,35,7],
 "group__API__Toolbox.html#ga9e7c20a6cdce868976a0046206b104e6":[7,35,3],
-"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[7,35,18],
-"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[7,35,20],
-"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[7,35,15],
+"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[7,35,19],
+"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[7,35,21],
+"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[7,35,16],
+"group__API__Toolbox.html#gad3ac8d7f5a35aa9c65dcca9915f9a750":[7,35,15],
 "group__API__Toolbox.html#gae07407908792f54312150228d70dbece":[7,35,5],
 "group__API__Toolbox.html#gae8c513ecd1a5bd87a7bdd71260c49ffc":[7,35,11],
 "group__API__Transactions.html":[7,7],
@@ -244,10 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#ga8c4e370ff327c38a3ec79c9249ab233a":[7,18,15],
 "group__API__Workers.html#ga8dc923de752528ca92c129c00af3703e":[7,18,70],
 "group__API__Workers.html#ga9381b07c96aa7d1d0e6edeb338b2fd94":[7,18,29],
-"group__API__Workers.html#ga95b8a935e52957f51659be8abad46668":[7,18,35],
-"group__API__Workers.html#ga9b2541fc1a20c4c486c499af01a3283c":[7,18,60],
-"group__API__Workers.html#gaa6e5fd90ba1b431ed025006d190fb421":[7,18,5],
-"group__API__Workers.html#gaa7a73dac05f65d5760abf29016e251f0":[7,18,3],
-"group__API__Workers.html#gaad05388dbafdd5397ebe080913a7b0c8":[7,18,19],
-"group__API__Workers.html#gaafe3ee2f7b074f95e8bc79eeabda0f0f":[7,18,4]
+"group__API__Workers.html#ga95b8a935e52957f51659be8abad46668":[7,18,35]
 };
