@@ -1,5 +1,7 @@
 var NAVTREEINDEX3 =
 {
+"group__API__Data__Management.html#ga8771ea54051655e68ed7a95b4b831fc7":[5,8,32],
+"group__API__Data__Management.html#ga88a1a866445372adf0a07a349ecc7a5a":[5,8,10],
 "group__API__Data__Management.html#ga8b98dee994de7c323a81ac6e573e5693":[5,8,49],
 "group__API__Data__Management.html#ga8bcfd56807cf9436eca71c6e3ade2dab":[5,8,41],
 "group__API__Data__Management.html#ga8db878885ebbee4729d8aed6a0479262":[5,8,22],
@@ -160,6 +162,7 @@ var NAVTREEINDEX3 =
 "group__API__Explicit__Dependencies.html":[5,11],
 "group__API__Explicit__Dependencies.html#ga19e120568fbd21fcac59b93ff324c45f":[5,11,4],
 "group__API__Explicit__Dependencies.html#ga1a93d3d46ea5ade29a3a3ea76b6eb90d":[5,11,8],
+"group__API__Explicit__Dependencies.html#ga2425f146494ef50105f99325f4120522":[5,11,18],
 "group__API__Explicit__Dependencies.html#ga2ab771900cf19e039ade46594dbc5fce":[5,11,3],
 "group__API__Explicit__Dependencies.html#ga53dc7bff09b441ee6a200cae99ca2cb8":[5,11,5],
 "group__API__Explicit__Dependencies.html#ga6d09446c8849f42edeced84c558e6a49":[5,11,17],
@@ -198,6 +201,7 @@ var NAVTREEINDEX3 =
 "group__API__FxT__Support.html#ad989ef1acebea5296285ba1543b9b8d3":[5,34,2,2],
 "group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c":[5,34,1,0],
 "group__API__FxT__Support.html#ae8b5695146698ba1d5aef8c9237b5272":[5,34,2,3],
+"group__API__FxT__Support.html#ga044878f9b946fd4c265ba6e725e2468c":[5,34,9],
 "group__API__FxT__Support.html#ga2e55ad671e94b6161755717b1c8b44c1":[5,34,7],
 "group__API__FxT__Support.html#ga52a3e1a95689315f0b789a3325ec2a90":[5,34,5],
 "group__API__FxT__Support.html#ga5793bf5c8fc0bedf76d18a5fa38593df":[5,34,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX3 =
 "group__API__Initialization__and__Termination.html#a30cab554913e27a02512badaf204a266":[5,4,0,20],
 "group__API__Initialization__and__Termination.html#a3a4c940d048e3805784624c51cb45195":[5,4,0,25],
 "group__API__Initialization__and__Termination.html#a3e62950f697167adcad7311d57178f80":[5,4,0,24],
-"group__API__Initialization__and__Termination.html#a3efb09a64357452502843f583b94e5dc":[5,4,0,40],
-"group__API__Initialization__and__Termination.html#a401add75734cfd9af675c28424e5977e":[5,4,0,23],
-"group__API__Initialization__and__Termination.html#a45cd3895b53b0bcd5c4cfe5dd534c714":[5,4,0,19],
-"group__API__Initialization__and__Termination.html#a46b9ccb6b1b2988ade6c7a446d60fd26":[5,4,0,2],
-"group__API__Initialization__and__Termination.html#a51036ff80225d75c5f8b83476da907c6":[5,4,0,48]
+"group__API__Initialization__and__Termination.html#a3efb09a64357452502843f583b94e5dc":[5,4,0,40]
 };
