@@ -1,5 +1,9 @@
 var NAVTREEINDEX4 =
 {
+"group__API__Initialization__and__Termination.html#a401add75734cfd9af675c28424e5977e":[5,4,0,23],
+"group__API__Initialization__and__Termination.html#a45cd3895b53b0bcd5c4cfe5dd534c714":[5,4,0,19],
+"group__API__Initialization__and__Termination.html#a46b9ccb6b1b2988ade6c7a446d60fd26":[5,4,0,2],
+"group__API__Initialization__and__Termination.html#a51036ff80225d75c5f8b83476da907c6":[5,4,0,48],
 "group__API__Initialization__and__Termination.html#a515df0a157b0bebc3e3aeaf6dd95bb73":[5,4,0,35],
 "group__API__Initialization__and__Termination.html#a53d18b801302e2ccae6af09c6cdbb2c5":[5,4,0,33],
 "group__API__Initialization__and__Termination.html#a58cc3a37dc4e60999c2c99b0ec0244ad":[5,4,0,1],
@@ -245,9 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__MPI__Support.html#ga541b21ab308db9784fe907827de74db3":[5,27,38],
 "group__API__MPI__Support.html#ga542e52a59609339359e8b8cfb694782a":[5,27,90],
 "group__API__MPI__Support.html#ga56d04ea3b1384624d5e5f54249b773e3":[5,27,66],
-"group__API__MPI__Support.html#ga5f09db3c837b6b44bc51dd5e6988afde":[5,27,32],
-"group__API__MPI__Support.html#ga633d2e3fef4861042eb42e214efa2e43":[5,27,42],
-"group__API__MPI__Support.html#ga63a3aa05bebafcc4b9cf67f73db6ecb6":[5,27,92],
-"group__API__MPI__Support.html#ga64b80afba4d16ef45a1baf4656a94c52":[5,27,81],
-"group__API__MPI__Support.html#ga67d1e5f67d39674590a2adc7c53ae185":[5,27,28]
+"group__API__MPI__Support.html#ga5f09db3c837b6b44bc51dd5e6988afde":[5,27,32]
 };
