@@ -1,5 +1,9 @@
 var NAVTREEINDEX8 =
 {
+"group__API__SC__Hypervisor.html#ae3a65239bb98f10756743787df0b9319":[5,47,2,1],
+"group__API__SC__Hypervisor.html#aea7e98763fa2b2f5553cc73bf29705f7":[5,47,1,0],
+"group__API__SC__Hypervisor.html#aec206144116e7360d2479a38a1c7f5f4":[5,47,1,3],
+"group__API__SC__Hypervisor.html#afbd8b91f7650ffd4c21ecbf17771a3d0":[5,47,2,9],
 "group__API__SC__Hypervisor.html#afdc378d28bfed82986912168bab0286b":[5,47,2,11],
 "group__API__SC__Hypervisor.html#ga022e4bef8fa4b4e68f071cbaa69c7dd5":[5,47,43],
 "group__API__SC__Hypervisor.html#ga035e61bdee7a98948b3c7e2e0b55ef21":[5,47,38],
@@ -245,9 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Standard__Memory__Library.html#ga4e9089680daf0b2d7f26e4657ffe9f48":[5,44,8],
 "group__API__Standard__Memory__Library.html#ga50b58997f2ab30eb82baab2cc7893a08":[5,44,15],
 "group__API__Standard__Memory__Library.html#ga52ec305b6afdd76130a4f6877e23849c":[5,44,9],
-"group__API__Standard__Memory__Library.html#ga552a99a9bb5c02acd10ed744c9c00a9d":[5,44,18],
-"group__API__Standard__Memory__Library.html#ga5a6ea6d03d7b0f4a97a8046b30ecd0bb":[5,44,16],
-"group__API__Standard__Memory__Library.html#ga67c2ba763b260bea998b16881c788ae6":[5,44,5],
-"group__API__Standard__Memory__Library.html#ga6ddda4b71de54cf079a84f7c4b683443":[5,44,29],
-"group__API__Standard__Memory__Library.html#ga71ec84f082fd96f53612e684eda0e178":[5,44,26]
+"group__API__Standard__Memory__Library.html#ga552a99a9bb5c02acd10ed744c9c00a9d":[5,44,18]
 };
