@@ -1,5 +1,9 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Profiling.html#ga858f465a2dcbcadb6169a7926e38a4d1":[7,40,12],
+"group__API__Profiling.html#ga87639260ff5c89f466e83fcc093e77fe":[7,40,20],
+"group__API__Profiling.html#ga8a423df93ec48a7391b2f439357a5544":[7,40,9],
+"group__API__Profiling.html#ga8cbf499dd0d62647b874fcb48c281e6a":[7,40,15],
 "group__API__Profiling.html#ga8dc4665fdbbbf8ce8f1b905aa8411642":[7,40,10],
 "group__API__Profiling.html#ga8ded3aa2a94ec7a5cd46e2e70a918c65":[7,40,13],
 "group__API__Profiling.html#ga9373d4a06c86ebf9ae74b67233b8bad6":[7,40,23],
@@ -245,9 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Policy.html#afd00e4e0a058e043c3d8edf916ace4f7":[7,24,0,7],
 "group__API__Scheduling__Policy.html#ga1e159d56ffa2d7705bdfd1ceb93e0d64":[7,24,36],
 "group__API__Scheduling__Policy.html#ga20525c5d674b32a9f64fbc9e23c5f55f":[7,24,23],
-"group__API__Scheduling__Policy.html#ga21385d19bc75a7581e774bd455c70790":[7,24,28],
-"group__API__Scheduling__Policy.html#ga24154b37920144de18bca59090429d6d":[7,24,18],
-"group__API__Scheduling__Policy.html#ga2bb5cf545414379c1425a4b399fd75c2":[7,24,6],
-"group__API__Scheduling__Policy.html#ga2c45db0c01e86497082c907b9cb0f4cc":[7,24,14],
-"group__API__Scheduling__Policy.html#ga2dc83adec9e479e967a1d1c2ae40f916":[7,24,30]
+"group__API__Scheduling__Policy.html#ga21385d19bc75a7581e774bd455c70790":[7,24,28]
 };
