@@ -1,5 +1,7 @@
 var NAVTREEINDEX1 =
 {
+"group__API__Codelet__And__Tasks.html#a52e061fbdb64f2e48569951ca4b253be":[6,6,2,37],
+"group__API__Codelet__And__Tasks.html#a555d04c028ae045636abfaf90ebb28df":[6,6,2,6],
 "group__API__Codelet__And__Tasks.html#a593418a8961318e4085177abeeaa43ad":[6,6,0,7],
 "group__API__Codelet__And__Tasks.html#a5b10ec927864df770f06cb307905128d":[6,6,2,65],
 "group__API__Codelet__And__Tasks.html#a5d93092cb2cd2a22be6b12846c4ed87d":[6,6,2,53],
@@ -247,7 +249,5 @@ var NAVTREEINDEX1 =
 "group__API__Data__Interfaces.html#a8de123492a76c7f674715f0613358ddd":[6,9,5,2],
 "group__API__Data__Interfaces.html#a8fca87a97f1f7d086377f4c40aec3f29":[6,9,9,0],
 "group__API__Data__Interfaces.html#a90c8cddece28b8576636e6ae4953a30f":[6,9,7,6],
-"group__API__Data__Interfaces.html#a94fe9c7865c4efd4ffacfeabedce1da7":[6,9,9,2],
-"group__API__Data__Interfaces.html#a975914df540caa34fd0f469d242e3a40":[6,9,0,10],
-"group__API__Data__Interfaces.html#a98ab405852ad8f5b23b4c305633a8761":[6,9,4,5]
+"group__API__Data__Interfaces.html#a94fe9c7865c4efd4ffacfeabedce1da7":[6,9,9,2]
 };
