@@ -1,5 +1,9 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Modularized__Scheduler.html#ga5c4ea8cd11d331eb39de2c02ce29efb1":[6,22,39],
+"group__API__Modularized__Scheduler.html#ga61c2f443fb8d5b6a2a1404eae0e7868e":[6,22,31],
+"group__API__Modularized__Scheduler.html#ga685a73facd82449b2f21f76f909e4ac3":[6,22,60],
+"group__API__Modularized__Scheduler.html#ga686ebaecfc562cacc98b20bbb7db5ebf":[6,22,34],
 "group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9":[6,22,59],
 "group__API__Modularized__Scheduler.html#ga6b1f65158357aae0d9239063e54f82a4":[6,22,21],
 "group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[6,22,27],
@@ -245,9 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Parallel__Tasks.html#ga3d362cb0de1da4e2659f602eff325479":[6,19,8],
 "group__API__Parallel__Tasks.html#ga49a6732f413550652450baa64594bc5e":[6,19,0],
 "group__API__Parallel__Tasks.html#ga4eb5aaf2f4e0c9a7f07cbc80f3ae9664":[6,19,4],
-"group__API__Parallel__Tasks.html#ga573d2513a10cf1d14fee0467eda0884d":[6,19,3],
-"group__API__Parallel__Tasks.html#ga5b81d2b58b724e33b7fcbb546464510a":[6,19,1],
-"group__API__Parallel__Tasks.html#ga720a70f5297ffe3b5ea5cf6eff549c8c":[6,19,6],
-"group__API__Parallel__Tasks.html#gae3fe82c940e36715145baa9fe003e453":[6,19,7],
-"group__API__Parallel__Tasks.html#gae53499613fb72e9aa1abad6437a926f9":[6,19,2]
+"group__API__Parallel__Tasks.html#ga573d2513a10cf1d14fee0467eda0884d":[6,19,3]
 };
