@@ -1,5 +1,9 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Parallel__Tasks.html#ga5b81d2b58b724e33b7fcbb546464510a":[6,19,1],
+"group__API__Parallel__Tasks.html#ga720a70f5297ffe3b5ea5cf6eff549c8c":[6,19,6],
+"group__API__Parallel__Tasks.html#gae3fe82c940e36715145baa9fe003e453":[6,19,7],
+"group__API__Parallel__Tasks.html#gae53499613fb72e9aa1abad6437a926f9":[6,19,2],
 "group__API__Parallel__Tasks.html#gaf99bc08bf6f586b658febdd1dc6fef80":[6,19,9],
 "group__API__Parallel__Worker.html":[6,37],
 "group__API__Parallel__Worker.html#ga01d8f8727b395aa7b49b77772b43f215":[6,37,1],
@@ -245,9 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling.html#a52240aa53000a12a7b913f9f5822e032":[6,40,1,15],
 "group__API__Profiling.html#a55f39da3b4c223d4cfc5bf7456692179":[6,40,0,3],
 "group__API__Profiling.html#a595e50d7029c774d275a4c60f16a0ada":[6,40,1,8],
-"group__API__Profiling.html#a5f76b7a4cc42a28735e0871439040319":[6,40,1,13],
-"group__API__Profiling.html#a650860076a4d4c07929e97ec64386724":[6,40,0,2],
-"group__API__Profiling.html#a67bee4aeadbec19556780f8328110957":[6,40,1,7],
-"group__API__Profiling.html#a6e85ac77428f572c5380e283b943459c":[6,40,0,16],
-"group__API__Profiling.html#a73a1303e033dffe94ff162e8e21122d1":[6,40,1,12]
+"group__API__Profiling.html#a5f76b7a4cc42a28735e0871439040319":[6,40,1,13]
 };
